@@ -1,5 +1,7 @@
 """
 Main CLI entrypoint.
+
+Copyright 2025 Vlad Emelianov
 """
 
 import sys
@@ -9,14 +11,14 @@ def print_info() -> None:
     """
     Print package info to stdout.
     """
-    print(
-        "Type annotations for boto3.CodeStarNotifications 1.35.0\n"
-        "Version:         1.35.0\n"
-        "Builder version: 7.26.0\n"
+    sys.stdout.write(
+        "Type annotations for boto3 CodeStarNotifications 1.42.3\n"
+        "Version:         1.42.3\n"
+        "Builder version: 8.12.0\n"
         "Docs:            https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications//\n"
-        "Boto3 docs:      https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codestar-notifications.html#CodeStarNotifications\n"
+        "Boto3 docs:      https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codestar-notifications.html#codestarnotifications\n"
         "Other services:  https://pypi.org/project/boto3-stubs/\n"
-        "Changelog:       https://github.com/youtype/mypy_boto3_builder/releases"
+        "Changelog:       https://github.com/youtype/mypy_boto3_builder/releases\n"
     )
 
 
@@ -24,7 +26,7 @@ def print_version() -> None:
     """
     Print package version to stdout.
     """
-    print("1.35.0")
+    sys.stdout.write("1.42.3\n")
 
 
 def main() -> None:
@@ -32,7 +34,8 @@ def main() -> None:
     Main CLI entrypoint.
     """
     if "--version" in sys.argv:
-        return print_version()
+        print_version()
+        return
     print_info()
 
 
